==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.md <==
# AmazonSimpleStorageServiceS3ObjectLambda


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')
```



| Illustration | AmazonSimpleStorageServiceS3ObjectLambda | AmazonSimpleStorageServiceS3ObjectLambdaCard | AmazonSimpleStorageServiceS3ObjectLambdaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambda](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambdaCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambdaCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambdaGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambdaGroup.Local.png) |




## AmazonSimpleStorageServiceS3ObjectLambda

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambda
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambda('AmazonSimpleStorageServiceS3ObjectLambda', 'Amazon Simple Storage Service S3 Object Lambda', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambda
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambda('AmazonSimpleStorageServiceS3ObjectLambda', 'Amazon Simple Storage Service S3 Object Lambda', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3ObjectLambdaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaCard('AmazonSimpleStorageServiceS3ObjectLambdaCard', 'Amazon Simple Storage Service S3 Object Lambda Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaCard('AmazonSimpleStorageServiceS3ObjectLambdaCard', 'Amazon Simple Storage Service S3 Object Lambda Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3ObjectLambdaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaGroup('AmazonSimpleStorageServiceS3ObjectLambdaGroup', 'Amazon Simple Storage Service S3 Object Lambda Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaGroup('AmazonSimpleStorageServiceS3ObjectLambdaGroup', 'Amazon Simple Storage Service S3 Object Lambda Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.md <==
# AmazonSimpleStorageServiceS3ObjectLambda


```text
aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda
```

```text
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')
```



| Illustration | AmazonSimpleStorageServiceS3ObjectLambda | AmazonSimpleStorageServiceS3ObjectLambdaCard | AmazonSimpleStorageServiceS3ObjectLambdaGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambda](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambdaCard](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambdaCard.Local.png) | ![illustration for AmazonSimpleStorageServiceS3ObjectLambdaGroup](../../../aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambdaGroup.Local.png) |




## AmazonSimpleStorageServiceS3ObjectLambda

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambda
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambda('AmazonSimpleStorageServiceS3ObjectLambda', 'Amazon Simple Storage Service S3 Object Lambda', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambda
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambda('AmazonSimpleStorageServiceS3ObjectLambda', 'Amazon Simple Storage Service S3 Object Lambda', 'an optional tech label')
@enduml
```

## AmazonSimpleStorageServiceS3ObjectLambdaCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaCard('AmazonSimpleStorageServiceS3ObjectLambdaCard', 'Amazon Simple Storage Service S3 Object Lambda Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaCard
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaCard('AmazonSimpleStorageServiceS3ObjectLambdaCard', 'Amazon Simple Storage Service S3 Object Lambda Card', 'an optional description')
@enduml
```

## AmazonSimpleStorageServiceS3ObjectLambdaGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaGroup('AmazonSimpleStorageServiceS3ObjectLambdaGroup', 'Amazon Simple Storage Service S3 Object Lambda Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleStorageServiceS3ObjectLambdaGroup
include('aws-q3-2021/Resource/Storage/AmazonSimpleStorageServiceS3ObjectLambda')

' renders the element
AmazonSimpleStorageServiceS3ObjectLambdaGroup('AmazonSimpleStorageServiceS3ObjectLambdaGroup', 'Amazon Simple Storage Service S3 Object Lambda Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
